| Title: | Toolbox for Downloading and Extracting Copernicus AgERA5 Data |
|---|---|
| Description: | Tools for downloading and extracting data from the Copernicus "Agrometeorological indicators from 1979 to present derived from reanalysis" <https://cds.climate.copernicus.eu/datasets/sis-agrometeorological-indicators?tab=overview> (AgERA5). |
| Authors: | David Brown [aut, cre] (ORCID: <https://orcid.org/0000-0003-2859-1618>), Kaue de Sousa [ctb] (ORCID: <https://orcid.org/0000-0002-7571-7845>), Jacob van Etten [ths] (ORCID: <https://orcid.org/0000-0001-7554-2558>), Sytze de Bruin [ths] (ORCID: <https://orcid.org/0000-0002-6884-2832>) |
| Maintainer: | David Brown <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.3 |
| Built: | 2026-05-25 07:04:21 UTC |
| Source: | https://github.com/agrdatasci/ag5tools |
The data is downloaded from Copernicus Climate Change Service (C3S) using the Copernicus Climate Data Store (CDSAPI) Python library https://github.com/ecmwf/cdsapi
This function provides programmatic access to the AgERA5 dataset. For more information about the data license, please visit: https://cds.climate.copernicus.eu/datasets/sis-agrometeorological-indicators?tab=overview
To download the data you should have a valid CDS account, an CDS API key. Please follow the instructions at: https://cds.climate.copernicus.eu/how-to-api to create a file to store your API key. You do not need to install Python or the cdsapi, Ag5Tools will do it if required.
ag5_download( variable, statistic = NULL, year, month, day, time = NULL, version = "1_1", path, area = NULL )ag5_download( variable, statistic = NULL, year, month, day, time = NULL, version = "1_1", path, area = NULL )
variable |
character The variable to be downloaded. See details |
statistic |
character Only required for some variables. See details for options. |
year |
numeric (Integer) Year to download. Should be between 1979 - 2022 |
month |
numeric Month to be requested. Use |
day |
numeric Days of the month for the requested data.
Use |
time |
Character Only required for "2m_relative_humidity". |
version |
Character Version 1_1 is currently the default and recommended See details for available options. |
path |
Character Target folder in an local hardrive e.g. "C:/agera5". The folder should exist and the user should have write permission. |
area |
A numeric vector of length = 4 Values represent geographic coordinates for the area of interest in this order (north, west, south, east). If NULL it will download the whole available region. |
No return value, called for side effects.
cloud_cover
liquid_precipitation_duration_fraction
snow_thickness_lwe
solar_radiation_flux
2m_temperature
2m_dewpoint_temperature
precipitation_flux
solid_precipitation_duration_fraction
snow_thickness
vapour_pressure
10m_wind_speed
2m_relative_humidity
Variable "2m_temperature" requires to indicate at least one of the following
options in statistic:
24_hour_maximum
24_hour_mean
24_hour_minimum
day_time_maximum
day_time_mean
night_time_mean
night_time_minimum
Variable "2m_relative_humidity" requires to indicate one of the following
options in time:
06_00
09_00
12_00
15_00
18_00
For the following variables, only "24_hour_mean" statistic is available, but should be explicitly indicated.
cloud_cover
snow_thickness_lwe
2m_dewpoint_temperature
snow_thickness
vapour_pressure
10m_wind_speed
## Not run: ag5_download(variable = "2m_temperature", statistic = "night_time_minimum", day = "all", month = "all", year = 2015, path = "C:/custom_target_folder" ) ## End(Not run)## Not run: ag5_download(variable = "2m_temperature", statistic = "night_time_minimum", day = "all", month = "all", year = 2015, path = "C:/custom_target_folder" ) ## End(Not run)
Extract data from AgERA5 data files previously downloaded from the Copernicus Climate Data Store.
These functions use package 'terra' to read *.nc files and extract the requested data for a given location
and dates. If dates is one value it extracts a single observation for the specified variable and location.
If dates is a character vector of length == 2, it will extract a time series of the specified variable
and location, where the first dates value is the start date and the second the end date.
ag5_extract(coords, ..., path) ## S3 method for class 'numeric' ag5_extract( coords, dates, variable, statistic = NULL, time = NULL, celsius = FALSE, parallel = TRUE, ..., path ) ## S3 method for class 'data.frame' ag5_extract( coords, lon = "lon", lat = "lat", start_date = "start_date", end_date = "end_date", variable, statistic = NULL, time = NULL, celsius = FALSE, ncores = NULL, ..., path )ag5_extract(coords, ..., path) ## S3 method for class 'numeric' ag5_extract( coords, dates, variable, statistic = NULL, time = NULL, celsius = FALSE, parallel = TRUE, ..., path ) ## S3 method for class 'data.frame' ag5_extract( coords, lon = "lon", lat = "lat", start_date = "start_date", end_date = "end_date", variable, statistic = NULL, time = NULL, celsius = FALSE, ncores = NULL, ..., path )
coords |
numeric vector of length = 2 of the form (lon, lat), or a |
... |
Other parameters |
path |
|
dates |
|
variable |
|
statistic |
|
time |
Only for variable Relative-Humidity-2m, see details for valid options |
celsius |
logical Only for variables "Temperature-Air-2m" and "2m_dewpoint_temperature". |
parallel |
logical Use parallel computation to speed-up data processing |
lon |
|
lat |
|
start_date |
|
end_date |
|
ncores |
Number of cores to use with parallel. If NULL and parallel is ON, half the available cores will be used.
If |
numeric vector with length equal to the number of dates between first and
second date. The returned vecter is a named vector, with requested dates as names.
If only one date is provided the function returns a numeric vector
with length = 1.
If coords is a data.frame, the function returns a list of
numeric vectors, each one corresponding to the rows in the input data.frame
"Cloud-Cover"
"Precipitation-Rain-Duration-Fraction"
"Snow-Thickness-LWE"
"Solar-Radiation-Flux"
"Temperature-Air-2m"
"Dew-Point_Temperature-2m"
"Precipitation-Flux"
"Precipitation-Solid-Duration-Fraction"
"Snow-Thickness"
"Vapour-Pressure"
"Wind-Speed-10m"
"Relative-Humidity-2m"
"Max-24h"
"Mean-24h"
"Min-24h"
"Max-Day-Time"
"Mean-Day-Time"
"Mean-Night-Time"
"Min-Night-Time"
For the following variables, only 24 hour mean statistic is available, but should be explicitly indicated as "Mean".
"Cloud-Cover"
"Snow-Thickness-LWE"
"Dew-Point_Temperature-2m"
"Snow-Thickness"
"Vapour-Pressure"
"Wind-Speed-10m"
"06h"
"09h"
"12h"
"15h"
"18h"
Temperature conversion is made accordingly to: Preston-Thomas, H. (1990). The International Temperature Scale of 1990 (ITS-90). Metrologia, 27(1), 3-10. doi:10.1088/0026-1394/27/1/002
## Not run: temp <- ag5_extract(coords = c(lon = 35.72636, lat = -2.197162), dates = "1991-04-22", variable = "Temperature-Air-2m", statistic = "Max-Day-Time", path = "C:/temperature_data/") ## End(Not run)## Not run: temp <- ag5_extract(coords = c(lon = 35.72636, lat = -2.197162), dates = "1991-04-22", variable = "Temperature-Air-2m", statistic = "Max-Day-Time", path = "C:/temperature_data/") ## End(Not run)
100 points in Arusha, Tanzania The geographic coordinates were generated with the function st_sample from package sf
arusha_dfarusha_df
An object of class data.frame with 100 rows and 4 columns.